import promClient from 'prom-client';
import express from 'express';
export default class Exporter {
    metricServer;
    logger;
    constructor(logger) {
        this.logger = logger.child({ module: 'prometheus_exporter' });
    }
    async create(promMetricsAPIConfig) {
        try {
            if (promMetricsAPIConfig.default_metrics) {
                const defaultMetricsConfig = {
                    prefix: promMetricsAPIConfig.prefix,
                    labels: promMetricsAPIConfig.labels
                };
                promClient.collectDefaultMetrics(defaultMetricsConfig);
            }
            const { port } = promMetricsAPIConfig;
            const app = express();
            app.get('/', async (_req, res) => {
                res.status(404).send('See the \'/metrics\' endpoint for the teraslice metric exporter\n');
            });
            app.get('/metrics', async (_req, res) => {
                res.set('Content-Type', promClient.register.contentType);
                res.end(await promClient.register.metrics());
            });
            this.metricServer = app.listen(port);
        }
        catch (err) {
            this.logger.error('Prometheus exporter creation failed: ', err);
        }
    }
    async shutdown() {
        this.metricServer.close();
    }
    async deleteMetric(name) {
        promClient.register.removeSingleMetric(name);
    }
    resetMetrics() {
        promClient.register.resetMetrics();
    }
}
//# sourceMappingURL=exporter.js.map