import { isString, isFunction } from '@terascope/utils';
import registerApis from './api/index.js';
/**
 * CoreContext
*/
export class CoreContext {
    cluster;
    sysconfig;
    apis;
    logger;
    name;
    arch = process.arch;
    platform = process.platform;
    assignment;
    cluster_name;
    constructor(config, cluster, sysconfig, assignment) {
        this.sysconfig = sysconfig;
        this.cluster = cluster;
        this.name = config.name || 'terafoundation';
        this.assignment = assignment || (process.env.NODE_TYPE
            || process.env.assignment
            || process.env.ASSIGNMENT);
        // set the process.title to make it easier to find the process
        if (config.name && this.assignment) {
            const separator = this.assignment.includes('-') ? '-' : '_';
            process.title = `${config.name}${separator}${this.assignment}`;
        }
        else if (config.name) {
            process.title = config.name;
        }
        if (isFunction(config.cluster_name)) {
            this.cluster_name = config.cluster_name(this.sysconfig);
        }
        if (isString(config.cluster_name)) {
            this.cluster_name = config.cluster_name;
        }
        registerApis(this);
    }
}
export function handleStdStreams() {
    // See https://github.com/trentm/node-bunyan/issues/246
    function handleStdError(err) {
        if (err.code === 'EPIPE' || err.code === 'ERR_STREAM_DESTROYED') {
            // ignore
        }
        else {
            throw err;
        }
    }
    process.stdout.on('error', handleStdError);
    process.stderr.on('error', handleStdError);
}
//# sourceMappingURL=core-context.js.map