import { nanoid } from 'nanoid';
import validateConfigs from './validate-configs.js';
import { CoreContext } from './core-context.js';
import { getArgs } from './sysconfig.js';
/**
 * A Single Process Context, this should be used when running
 * in a single process instance/container. This context doesn't
 * support some of the multiple worker/assignment variations
 * that `ClusterContext` does, like `master` or `worker`.
 *
 * @todo add process event handler listeners in initialize method
 * @todo add shutdown handler logic with shutdown method
*/
export class ProcessContext extends CoreContext {
    static async createContext(config, overrideArgs) {
        const cluster = {
            isMaster: false,
            worker: {
                id: nanoid(8),
            }
        };
        const parsedArgs = overrideArgs || await getArgs(config.default_config_file);
        const sysconfig = await validateConfigs(cluster, config, parsedArgs.configfile);
        return new ProcessContext(config, cluster, sysconfig);
    }
}
//# sourceMappingURL=process-context.js.map